ErrorKind

Enum ErrorKind 

#[non_exhaustive]
pub enum ErrorKind {
Show 15 variants JsonParsing(JsonError), Web { message: String, }, Io(Error), InvalidResponse { response: String, }, Header, UnableToSerializeGoogleOAuthToken { response: String, err: Error, }, UnableToParseYtCfg { ytcfg: String, }, NoVisitorData, InvalidUserAgent(String), OAuthTokenExpired { token_hash: u64, }, OtherErrorCodeInResponse { code: u64, message: String, }, ApiStatusFailed, SystemTimeError { message: String, }, InvalidUploadFilename { filename: String, message: String, }, MissingUploadUrl,
}
The kind of the error. This list may grow over time, and it’s not recommended to exhaustively match on it.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


JsonParsing(JsonError)

Error parsing Json response from InnerTube.



Web

Error from HTTP client.

Fields

message: String


Io(Error)

General io error.



InvalidResponse

Received a response from InnerTube that was not in the expected (JSON) format.

Fields

response: String


Header

InnerTube credential header not in expected format.



UnableToSerializeGoogleOAuthToken

Fields

response: String
err: Error


UnableToParseYtCfg

ytcfg not in expected format.

Fields

ytcfg: String


NoVisitorData

ytcfg didn’t include visitor data.



InvalidUserAgent(String)

InnerTube rejected the User Agent we are using.



OAuthTokenExpired

OAuthToken has expired. Returns a hash of the expired token generated using the default hasher.

Fields

token_hash: u64


OtherErrorCodeInResponse

Recieved an error code in the Json reply from InnerTube.

Fields

code: u64
message: String


ApiStatusFailed

Innertube returned a STATUS_FAILED for the query.



SystemTimeError

Unable to obtain system time for the query to Innertube.

Fields

message: String


InvalidUploadFilename

Tried to upload a song with an invalid upload filename.

Fields

filename: String
message: String


MissingUploadUrl