Module json

This module contains the representation of Json exposed in the default public API in this library.

Structs

Json
Basic representation of any valid Json value, wrapping a serde_json::Value. For use if you are implementing crate::query::Query from scratch. To parse this value, you can utilise the Serialize / Deserialize traits, the from_json function to convert to a concrete type, or enable the serde_json feature to expose the internals via feature gated function Json::into_inner.

Functions

from_json
Interpret Json as an instance of type T. See crate::parse for a usage example.