#[non_exhaustive]pub struct GetArtistAlbums {
pub results: Vec<AlbumResult>,
pub browse_id: Option<ArtistChannelID<'static>>,
pub params: Option<BrowseParams<'static>>,
}Expand description
The Albums section of the Browse Artist page. The browse_id and params can be used to get the full list of artist’s albums. If they aren’t set, and results is not empty, you can assume that all albums are displayed here already.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.results: Vec<AlbumResult>browse_id: Option<ArtistChannelID<'static>>params: Option<BrowseParams<'static>>Trait Implementations
Sourceimpl Clone for GetArtistAlbums
impl Clone for GetArtistAlbums
Sourcefn clone(&self) -> GetArtistAlbums
fn clone(&self) -> GetArtistAlbums
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetArtistAlbums
impl Debug for GetArtistAlbums
Sourceimpl<'de> Deserialize<'de> for GetArtistAlbums
impl<'de> Deserialize<'de> for GetArtistAlbums
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for GetArtistAlbums
impl PartialEq for GetArtistAlbums
Sourceimpl Serialize for GetArtistAlbums
impl Serialize for GetArtistAlbums
impl StructuralPartialEq for GetArtistAlbums