#[non_exhaustive]pub struct TopResult {
pub result_name: String,
pub result_type: Option<TopResultType>,
pub thumbnails: Vec<Thumbnail>,
pub artist: Option<String>,
pub album: Option<String>,
pub duration: Option<String>,
pub year: Option<String>,
pub subscribers: Option<String>,
pub plays: Option<String>,
pub publisher: Option<String>,
pub byline: Option<String>,
}Expand description
Dynamically defined top result. Some fields are optional as they are not defined for all result types.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.result_name: Stringresult_type: Option<TopResultType>Both Videos and Songs can have this left out.
thumbnails: Vec<Thumbnail>artist: Option<String>album: Option<String>duration: Option<String>year: Option<String>subscribers: Option<String>plays: Option<String>publisher: Option<String>Podcast publisher.
byline: Option<String>Generic tagline that can appear on top results