Module create

Structs

BasicCreatePlaylist
Helper struct for CreatePlaylistQuery
CreatePlaylistFromPlaylist
Helper struct for CreatePlaylistQuery
CreatePlaylistFromVideos
Helper struct for CreatePlaylistQuery
CreatePlaylistQuery
A playlist can be created using a list of video ids, or as a copy of an existing playlist (but not both at the same time).

Traits

CreatePlaylistType