pub struct CreatePlaylistQuery<'a, C: CreatePlaylistType> { /* private fields */ }Expand description
A playlist can be created using a list of video ids, or as a copy of an existing playlist (but not both at the same time).
Implementations
Sourceimpl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
impl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
pub fn new( title: &'a str, description: Option<&'a str>, privacy_status: PrivacyStatus, ) -> CreatePlaylistQuery<'a, BasicCreatePlaylist>
Sourceimpl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
impl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
pub fn with_source<T: Into<PlaylistID<'a>>>( self, source_playlist: T, ) -> CreatePlaylistQuery<'a, CreatePlaylistFromPlaylist<'a>>
Sourceimpl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
impl<'a> CreatePlaylistQuery<'a, BasicCreatePlaylist>
pub fn with_video_ids( self, video_ids: impl IntoIterator<Item = VideoID<'a>>, ) -> CreatePlaylistQuery<'a, CreatePlaylistFromVideos<'a>>