pub trait Query<A: AuthToken>: Sized {
type Output: ParseFrom<Self>;
type Method: QueryMethod<Self, A>;
}Expand description
Represents a query that can be passed to Innertube. The Output associated type describes how to parse a result from the query, and the Method associated type describes how to call the query.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.