pub struct Client { /* private fields */ }Expand description
Basic HTTP client using TLS wrapping a reqwest::Client,
with the minimum required features to call YouTube Music queries.
Clone is low cost, internals of reqwest::Client are wrapped in an Arc.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Utilises reqwest’s default tls choice for the enabled set of options.
Sourcepub fn new_rustls_tls() -> Result<Self>
Available on crate feature rustls-tls only.
pub fn new_rustls_tls() -> Result<Self>
rustls-tls only.Force the use of rustls-tls
Sourcepub fn new_native_tls() -> Result<Self>
Available on crate feature native-tls only.
pub fn new_native_tls() -> Result<Self>
native-tls only.Force the use of native-tls
Sourcepub fn new_from_reqwest_client(client: Client) -> Self
Available on crate feature reqwest only.
pub fn new_from_reqwest_client(client: Client) -> Self
reqwest only.Re-use a pre-existing reqwest::Client.
Sourcepub async fn post_query<'a, I>(
&self,
url: impl AsRef<str>,
headers: impl IntoIterator<IntoIter = I>,
body: Body,
params: &(impl Serialize + ?Sized),
) -> Result<QueryResponse>
pub async fn post_query<'a, I>( &self, url: impl AsRef<str>, headers: impl IntoIterator<IntoIter = I>, body: Body, params: &(impl Serialize + ?Sized), ) -> Result<QueryResponse>
Run a POST query, with url, body, key/kalue params and headers.
Sourcepub async fn post_json_query<'a, I>(
&self,
url: impl AsRef<str>,
headers: impl IntoIterator<IntoIter = I>,
body_json: &(impl Serialize + ?Sized),
params: &(impl Serialize + ?Sized),
) -> Result<QueryResponse>
pub async fn post_json_query<'a, I>( &self, url: impl AsRef<str>, headers: impl IntoIterator<IntoIter = I>, body_json: &(impl Serialize + ?Sized), params: &(impl Serialize + ?Sized), ) -> Result<QueryResponse>
Run a POST query, with url, body serialisable to json, key/kalue params and headers.