ProcessedResult

Struct ProcessedResult 

pub struct ProcessedResult<'a, Q> {
    pub query: &'a Q,
    pub source: String,
    pub json: Json,
}
A result from the api that has been checked for errors and processed into JSON.

Fields

query: &'a Qsource: String

The raw string output returned from the web request to YouTube.

json: Json

The result once it has been deserialized from Json and processed to remove errors.

Implementations

Source

impl<Q> ProcessedResult<'_, Q>

pub fn parse_into<O: ParseFrom<Q>>(self) -> Result<O>