Struct RawResult

pub struct RawResult<'a, Q, A>
where Q: Query<A>, A: AuthToken,
{ pub query: &'a Q, pub json: String, /* private fields */ }
The raw result of a query to the API.

Fields

query: &'a Q

The query that generated this RawResult.

json: String

The raw string output returned from the web request to YouTube.

Implementations

Source

impl<'a, Q: Query<A>, A: AuthToken> RawResult<'a, Q, A>

pub fn from_raw(json: String, query: &'a Q) -> Self

pub fn destructure_json(self) -> String

pub fn process(self) -> Result<ProcessedResult<'a, Q>>