Module to contain code related to errors that could be produced by the API.
Structs
Enums
- Error
Kind - The kind of the error. This list may grow over time, and it’s not recommended to exhaustively match on it.
- Parse
Target - The type we were attempting to pass from the Json.
Type Aliases
- Result
- Alias for a Result with the error type ytmapi-rs::Error.