Module to contain code related to errors that could be produced by the API.
Structs
- This type represents all errors this API could produce.
Enums
- The kind of the error. This list may grow over time, and it’s not recommended to exhaustively match on it.
- The type we were attempting to pass from the Json.
Type Aliases
- Alias for a Result with the error type ytmapi-rs::Error.