#[non_exhaustive]pub enum ErrorKind {
Show 15 variants
JsonParsing(JsonError),
Web {
message: String,
},
Io(Error),
InvalidResponse {
response: String,
},
Header,
UnableToSerializeGoogleOAuthToken {
response: String,
err: Error,
},
UnableToParseYtCfg {
ytcfg: String,
},
NoVisitorData,
InvalidUserAgent(String),
OAuthTokenExpired {
token_hash: u64,
},
OtherErrorCodeInResponse {
code: u64,
message: String,
},
ApiStatusFailed,
SystemTimeError {
message: String,
},
InvalidUploadFilename {
filename: String,
message: String,
},
MissingUploadUrl,
}Expand description
The kind of the error. This list may grow over time, and it’s not recommended to exhaustively match on it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
JsonParsing(JsonError)
Error parsing Json response from InnerTube.
Web
Error from HTTP client.
Io(Error)
General io error.
InvalidResponse
Received a response from InnerTube that was not in the expected (JSON) format.
Header
InnerTube credential header not in expected format.
UnableToSerializeGoogleOAuthToken
UnableToParseYtCfg
ytcfg not in expected format.
NoVisitorData
ytcfg didn’t include visitor data.
InvalidUserAgent(String)
InnerTube rejected the User Agent we are using.
OAuthTokenExpired
OAuthToken has expired. Returns a hash of the expired token generated using the default hasher.
OtherErrorCodeInResponse
Recieved an error code in the Json reply from InnerTube.
ApiStatusFailed
Innertube returned a STATUS_FAILED for the query.
SystemTimeError
Unable to obtain system time for the query to Innertube.
InvalidUploadFilename
Tried to upload a song with an invalid upload filename.
MissingUploadUrl