#[non_exhaustive]pub enum ErrorKind {
JsonParsing(JsonError),
Web {
message: String,
},
Io(Error),
InvalidResponse {
response: String,
},
Header,
UnableToSerializeGoogleOAuthToken {
response: String,
err: Error,
},
InvalidUserAgent(String),
BrowserAuthenticationFailed,
OAuthTokenExpired {
token_hash: u64,
},
OtherErrorCodeInResponse {
code: u64,
message: String,
},
ApiStatusFailed,
SystemTimeError {
message: String,
},
}Expand description
The kind of the error. This list may grow over time, and it’s not recommended to exhaustively match on it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
JsonParsing(JsonError)
Error parsing Json response from InnerTube.
Web
Error from HTTP client.
Io(Error)
General io error.
InvalidResponse
Received a response from InnerTube that was not in the expected (JSON) format.
Header
InnerTube credential header not in expected format.
UnableToSerializeGoogleOAuthToken
InvalidUserAgent(String)
InnerTube rejected the User Agent we are using.
BrowserAuthenticationFailed
Failed to authenticate using Browse Auth credentials (may have expired, or been incorrectly provided).
OAuthTokenExpired
OAuthToken has expired. Returns a hash of the expired token generated using the default hasher.
OtherErrorCodeInResponse
Recieved an error code in the Json reply from InnerTube.
ApiStatusFailed
Innertube returned a STATUS_FAILED for the query.
SystemTimeError
Unable to obtain system time for the query to Innertube.