This module contains the representation of Json exposed in the default public API in this library.
Structs
- Json
- Basic representation of any valid Json value, wrapping a
serde_json::Value. For use if you are implementingcrate::query::Queryfrom scratch. To parse this value, you can utilise the Serialize / Deserialize traits, thefrom_jsonfunction to convert to a concrete type, or enable theserde_jsonfeature to expose the internals via feature gated functionJson::into_inner.
Functions
- from_
json - Interpret Json as an instance of type T.
See
crate::parsefor a usage example.