pub struct Json { /* private fields */ }Expand description
Basic representation of any valid Json value, wrapping a
serde_json::Value. For use if you are implementing crate::query::Query
from scratch. To parse this value, you can utilise the Serialize /
Deserialize traits, the from_json function to convert to a concrete
type, or enable the serde_json feature to expose the internals via feature
gated function Json::into_inner.
Note
This struct does not implement Deserializer, as implementation is more complex than this thin wrapper.
Implementations