Results from parsing Innertube queries.
Implementation example
use serde::Deserialize;
#[derive(Debug, Deserialize)]
struct Date {
date_string: String,
date_timestamp: usize,
}
impl ytmapi_rs::parse::ParseFrom<GetDateQuery> for Date {
fn parse_from(
p: ytmapi_rs::parse::ProcessedResult<GetDateQuery>,
) -> ytmapi_rs::Result<Self> {
ytmapi_rs::json::from_json(p.json)
}
}Alternative implementation
An alternative to working directly with crate::json::Json is to add
json-crawler as a dependency and use the provided
From<ProcessedResult> for JsonCrawlerOwned implementation.
Structs
- AddPlaylist
Item - Provides a SetVideoID and VideoID for each video added to the playlist.
- Album
Result - Album
Song - Artist
Song - Episode
- GetAlbum
- GetArtist
- GetArtist
Albums - The Albums section of the Browse Artist page. The browse_id and params can be used to get the full list of artist’s albums. If they aren’t set, and results is not empty, you can assume that all albums are displayed here already.
- GetArtist
Albums Album - GetArtist
Related - GetArtist
Songs - GetArtist
TopReleases - GetArtist
Videos - GetEpisode
- GetLibrary
Artist Subscription - GetLibrary
Upload Album - GetLibrary
Upload Album Song - GetPlaylist
Details - GetPodcast
- GetPodcast
Channel - GetPodcast
Channel Playlist - GetPodcast
Channel Podcast - GetUser
- History
Item Episode - History
Item Song - History
Item Upload Song - History
Item Video - History
Period - Library
Artist - Library
Artist Subscription - Library
Channel - Library
Playlist - Library
Podcast - Lyrics
- Mood
Category - Mood
Category Section - Mood
Playlist - Mood
Playlist Category - Parsed
Podcast Channel - Parsed
Song Album - Parsed
Song Artist - Parsed
Upload Artist - Parsed
Upload Song Album - Playlist
Episode - Playlist
Song - Playlist
Upload Song - Playlist
Video - Processed
Result - A result from the api that has been checked for errors and processed into JSON.
- Related
Result - Search
Result Album - An album search result.
- Search
Result Artist - An artist search result.
- Search
Result Community Playlist - A community playlist search result.
- Search
Result Episode - A podcast episode search result.
- Search
Result Featured Playlist - A featured playlist search result.
- Search
Result Podcast - A podcast search result.
- Search
Result Profile - A profile search result.
- Search
Result Song - Search
Results - Table
List Song - Table
List Upload Song - Taste
Profile Artist - TopResult
- Dynamically defined top result. Some fields are optional as they are not defined for all result types.
- Upload
Album - Upload
Artist - User
Playlist - User
Video - Watch
Playlist Track
Enums
- Basic
Search Result Community Playlist - Episode
Date - Episode
Duration - History
Item - InLiked
Songs - In some contexts, dislike will also be classified as indifferent.
- IsSaved
- Playlist
Item - Podcast
Channel TopResult - Podcast
Source - Search
Result Playlist - Search
Result Video - A video search result. May be a video or a video episode of a podcast.
- TopResult
Type - Each Top Result has it’s own type.
Traits
- Parse
From - Describes how to parse the ProcessedResult from a Query into the target type.