Results from parsing Innertube queries.
Implementation example
use serde::Deserialize;
#[derive(Debug, Deserialize)]
struct Date {
date_string: String,
date_timestamp: usize,
}
impl ytmapi_rs::parse::ParseFrom<GetDateQuery> for Date {
fn parse_from(
p: ytmapi_rs::parse::ProcessedResult<GetDateQuery>,
) -> ytmapi_rs::Result<Self> {
ytmapi_rs::json::from_json(p.json)
}
}Alternative implementation
An alternative to working directly with crate::json::Json is to add
json-crawler as a dependency and use the provided
From<ProcessedResult> for JsonCrawlerOwned implementation.
Structs
- Provides a SetVideoID and VideoID for each video added to the playlist.
- The Albums section of the Browse Artist page. The browse_id and params can be used to get the full list of artist’s albums. If they aren’t set, and results is not empty, you can assume that all albums are displayed here already.
- A result from the api that has been checked for errors and processed into JSON.
- An album search result.
- An artist search result.
- A community playlist search result.
- A podcast episode search result.
- A featured playlist search result.
- A podcast search result.
- A profile search result.
- Dynamically defined top result. Some fields are optional as they are not defined for all result types.
Enums
- In some contexts, dislike will also be classified as indifferent.
- A video search result. May be a video or a video episode of a podcast.
- Each Top Result has it’s own type.
Traits
- Describes how to parse the ProcessedResult from a Query into the target type.