Structs
- Basic
Create Playlist - Helper struct for CreatePlaylistQuery
- Create
Playlist From Playlist - Helper struct for CreatePlaylistQuery
- Create
Playlist From Videos - Helper struct for CreatePlaylistQuery
- Create
Playlist Query - A playlist can be created using a list of video ids, or as a copy of an existing playlist (but not both at the same time).