pub trait Query<A: AuthToken>: Sized {
type Output: ParseFrom<Self>;
type Method: QueryMethod<Self, A, Self::Output>;
}Expand description
Represents a query that can be passed to Innertube. The Output associated type describes how to parse a result from the query, and the Method associated type describes how to call the query.
Required Associated Types
Object Safety
This trait is not object safe.