Trait ytmapi_rs::query::QueryMethod
source · pub trait QueryMethod<Q, A, O>: Sealed{
// Required method
async fn call<'a>(
query: &'a Q,
client: &Client,
tok: &A,
) -> Result<RawResult<'a, Q, A>>;
}Expand description
Represents a method of calling an query, using a query, client and auth token. Not intended to be implemented by api users, the pre-implemented GetMethod and PostMethod structs should be sufficient, and in addition, async methods are required currently.
Required Methods
Object Safety
This trait is not object safe.