Struct ytmapi_rs::Client

source ·
pub struct Client { /* private fields */ }
Basic HTTP client using TLS wrapping a reqwest::Client, with the minimum required features to call YouTube Music queries. Clone is low cost, internals of reqwest::Client are wrapped in an Arc.

Implementations

source

impl Client

source

pub fn new() -> Result<Self>

Utilises reqwest’s default tls choice for the enabled set of options.

source

pub fn new_rustls_tls() -> Result<Self>

Available on crate feature rustls-tls only.

Force the use of rustls-tls

source

pub fn new_native_tls() -> Result<Self>

Available on crate feature native-tls only.

Force the use of native-tls

source

pub async fn post_query<'a, I>( &self, url: impl AsRef<str>, headers: impl IntoIterator<IntoIter = I>, body_json: &(impl Serialize + ?Sized), ) -> Result<String>
where I: Iterator<Item = (&'a str, Cow<'a, str>)>,

Run a POST query, with url and headers. Result is returned as a String.

source

pub async fn get_query<'a, I>( &self, url: impl AsRef<str>, headers: impl IntoIterator<IntoIter = I>, params: &(impl Serialize + ?Sized), ) -> Result<String>
where I: Iterator<Item = (&'a str, Cow<'a, str>)>,

Run a GET query, with url, key/value params and headers. Result is returned as a String.