pub struct ProcessedResult<'a, Q> {
pub query: &'a Q,
pub source: String,
pub json: Json,
}Expand description
A result from the api that has been checked for errors and processed into JSON.
Fields
query: &'a Qsource: StringThe raw string output returned from the web request to YouTube.
json: JsonThe result once it has been deserialized from Json and processed to remove errors.
Implementations
Sourceimpl<Q> ProcessedResult<'_, Q>
impl<Q> ProcessedResult<'_, Q>
pub fn parse_into<O: ParseFrom<Q>>(self) -> Result<O>