pub struct RawResult<'a, Q, A>{
pub query: &'a Q,
pub json: String,
/* private fields */
}Expand description
The raw result of a query to the API.
Fields
query: &'a QThe query that generated this RawResult.
json: StringThe raw string output returned from the web request to YouTube.
Implementations